Skip to main content Crate gpui_component Copy item path Source pub use theme ::*;accordion alert animation attachment avatar badge breadcrumb bubble button calendar chart checkbox clipboard collapsible color_picker combobox command A command palette: a search field over a filtered list of commands, with
groups, Action keybinding hints and keyboard navigation. date_picker description_list dialog dock The gpui-component appearance for the dock. form global_state group_box highlighter history hover_card input kbd label link list marker menu message message_scroller native_menu A menu rendered natively by the operating system. notification pagination plot popover progress radio rating resizable Backwards-compatible resizable component paths. scroll searchable_list select separator setting sheet shimmer sidebar skeleton slider spinner status_bar stepper switch tab table tag text Compatibility facade for rich text now owned by gpui-base. theme tooltip tree icon_named Generate a custom icon enum and its IconNamed impl by scanning a directory of SVG files. AnyChildElement A type-erased element that can accept a [AnyChildElementOptions] before being rendered. DivInspector Edges A struct for defining the edges of an element. GlobalState Application-wide state shared by Base behaviors. Icon IndexPath Represents an index path in a list, which consists of a section index, Measure An elapsed-time measurement emitted through tracing when ended. ResizablePanel A resizable panel inside a ResizablePanelGroup . ResizablePanelGroup A group of resizable panels. ResizableState State for a ResizablePanel Root Root is a view for the App window for as the top level view (Must be the first view in the window). Rope A utf8 text rope. RopeLines An iterator over the lines of a Rope. TitleBar TitleBar used to customize the appearance of the title bar. ToggleInspector VirtualList VirtualList component for rendering a large number of differently sized items. VirtualListScrollHandle A scroll handle for VirtualList . WindowBorder Renders a custom window border and shadow on Linux. IconName Default component icon names, retained for source compatibility.
For the complete Lucide catalog, use gpui_kit_assets::IconName. Placement A enum for defining the placement of the element. ResizablePanelEvent RoleOverride Side A enum for defining the side of the element. Size A size for elements. TITLE_BAR_HEIGHT AxisExt A trait to extend the Axis enum with utility methods. ChildElement Collapsible An element or component that exposes collapsed state. Disableable An element or component that can be disabled. ElementExt Extends a GPUI parent element with post-layout prepaint observation. FocusTrapElement An extension trait to add focus_trap functionality to interactive elements. FocusableExt A component that exposes whether its UI layer should draw a focus ring. IconNameExt Component view construction for the shared gpui_kit_assets::IconName.
The legacy component IconName retains its inherent view method. IconNamed A named icon that resolves to a path in an application’s asset source.
Implement this for custom icon sets accepted by GPUI Component’s Icon. InteractiveElementExt LengthExt A trait to extend the Length enum with utility methods. OngoingScrollExt gpui delimits scroll gestures with std::time::Instant, which is
unimplemented on wasm32: the first wheel event over an axis-locked scroll
area panics with “time not implemented on this platform” and takes the whole
application down, leaving the canvas unresponsive. Losing the axis lock in
the browser is by far the lesser cost, so the locks below are no-ops there. RopeExt An extension trait for Rope to provide additional utility methods. Selectable An element or component that exposes controlled selected state. Sizable A trait for setting the size of an element.
Size::Medium is use by default. StyleSized StyledExt ThemeStyled Finished styles that read the theme. WindowExt Extension trait for Window to add dialog, sheet .. functionality. box_shadow h_flex A row that centers its children on the cross axis. h_resizable Create a ResizablePanelGroup with horizontal resizing h_virtual_list Create a VirtualList in horizontal direction. init Initialize the components. locale measure Measures f when measurement logging is enabled. measure_if Measures f when if_ is true and measurement logging is enabled. resizable_panel Create a ResizablePanel . set_locale v_flex A column whose children stretch across the cross axis. v_resizable Create a ResizablePanelGroup with vertical resizing v_virtual_list Create a VirtualList in vertical direction. window_border Create a new window border. window_paddings Get the window paddings.