pub struct EffectTransition {
pub duration: Duration,
/* private fields */
}Expand description
A composable transition that applies concrete fade, slide, and size effects to an element.
This is distinct from crate::motion::Transition, which is a timing
policy for a caller-chosen value and never picks a visual property. Prefer
motion for new code.
Example
ⓘ
EffectTransition::new(Duration::from_millis(150))
.ease(ease_out_cubic)
.slide_y(px(-4.), px(0.))
.fade(0.0, 1.0)
.apply(element, "enter-anim")Fields
duration: DurationImplementations
Sourceimpl EffectTransition
impl EffectTransition
pub fn new(duration: Duration) -> EffectTransition
Sourcepub fn ease(self, easing: impl Fn(f32) -> f32 + 'static) -> EffectTransition
pub fn ease(self, easing: impl Fn(f32) -> f32 + 'static) -> EffectTransition
Set the easing function.
Sourcepub fn slide_y(self, from: Pixels, to: Pixels) -> EffectTransition
pub fn slide_y(self, from: Pixels, to: Pixels) -> EffectTransition
Animate vertical offset from from to to.
Sourcepub fn slide_x(self, from: Pixels, to: Pixels) -> EffectTransition
pub fn slide_x(self, from: Pixels, to: Pixels) -> EffectTransition
Animate horizontal offset from from to to.
Sourcepub fn fade(self, from: f32, to: f32) -> EffectTransition
pub fn fade(self, from: f32, to: f32) -> EffectTransition
Animate opacity from from to to.
Sourcepub fn width(self, from: Pixels, to: Pixels) -> EffectTransition
pub fn width(self, from: Pixels, to: Pixels) -> EffectTransition
Animate width from from to to.
Sourcepub fn height(self, from: Pixels, to: Pixels) -> EffectTransition
pub fn height(self, from: Pixels, to: Pixels) -> EffectTransition
Animate height from from to to.
Sourcepub fn apply<E>(
self,
element: E,
id: impl Into<ElementId>,
) -> AnimationElement<E>where
E: IntoElement + Styled + 'static,
pub fn apply<E>(
self,
element: E,
id: impl Into<ElementId>,
) -> AnimationElement<E>where
E: IntoElement + Styled + 'static,
Apply this transition to a Styled element, returning an AnimationElement.