Module carousel

Module carousel 

Structs

Carousel
A composable carousel root.
CarouselContent
The clipped viewport and snap track for Carousel items.
CarouselItem
One logical slide in a CarouselContent.
CarouselNext
A next-slide control positioned around the Carousel viewport.
CarouselPagination
A composable container for Carousel pagination items.
CarouselPaginationItem
One application-styled pagination control for a Carousel item.
CarouselPrevious
A previous-slide control positioned around the Carousel viewport.
CarouselState
Shared behavior state for every part of a super::Carousel.

Enums

CarouselEvent
An event emitted when user interaction selects another carousel item.