Clipboard

Struct Clipboard 

pub struct Clipboard { /* private fields */ }
An element that provides clipboard copy functionality.

Implementations

Source

impl Clipboard

pub fn new(id: impl Into<ElementId>) -> Self

Create a new Clipboard element with the given ID.

pub fn tooltip(self, tooltip: impl Into<SharedString>) -> Self

Set tooltip text for the clipboard button.

pub fn value(self, value: impl Into<SharedString>) -> Self

Set the value for copying to the clipboard. Default is an empty string.

pub fn value_fn( self, value: impl Fn(&mut Window, &mut App) -> SharedString + 'static, ) -> Self

Set the value of the clipboard to the result of the given function. Default is None.

When used this, the copy value will use the result of the function.

pub fn on_copied<F>(self, handler: F) -> Self
where F: Fn(SharedString, &mut Window, &mut App) + 'static,

Set a callback to be invoked when the content is copied to the clipboard.