pub enum CommandEntry {
Item(CommandItem),
Group(CommandGroup),
Separator,
}Expand description
A top-level entry in a crate::command::Command.
Variants
Item(CommandItem)
A single ungrouped item.
Group(CommandGroup)
A titled group of items.
Separator
A divider between groups.
A separator that ends up leading, trailing, or next to another separator once the query has filtered the list is not rendered.