pub struct CommandGroup { /* private fields */ }Expand description
A titled section of CommandItems.
The heading is hidden while every item in the group is filtered out.
Implementations
Sourceimpl CommandGroup
impl CommandGroup
Sourcepub fn label(self, label: impl Into<SharedString>) -> Self
pub fn label(self, label: impl Into<SharedString>) -> Self
Set the label displayed above the group’s items.
Sourcepub fn item(self, item: CommandItem) -> Self
pub fn item(self, item: CommandItem) -> Self
Add an item to the group.
Sourcepub fn items(self, items: impl IntoIterator<Item = CommandItem>) -> Self
pub fn items(self, items: impl IntoIterator<Item = CommandItem>) -> Self
Add multiple items to the group.
Sourcepub fn heading(&self) -> Option<&SharedString>
pub fn heading(&self) -> Option<&SharedString>
The heading of the group, when it has one.