pub enum DateTime {
Single(Option<NaiveDateTime>),
Range(Option<NaiveDateTime>, Option<NaiveDateTime>),
}Expand description
The value of a DatePicker: the selected date or dates combined with
their times of day.
When the picker has no time precision, every time is the picker’s
DatePickerState::default_time, 00:00 unless configured.
Variants
Single(Option<NaiveDateTime>)
Range(Option<NaiveDateTime>, Option<NaiveDateTime>)
Implementations
Sourceimpl DateTime
impl DateTime
pub fn is_some(&self) -> bool
pub fn is_complete(&self) -> bool
pub fn start(&self) -> Option<NaiveDateTime>
pub fn end(&self) -> Option<NaiveDateTime>
Sourcepub fn format(&self, format: &str) -> Option<SharedString>
pub fn format(&self, format: &str) -> Option<SharedString>
Format a complete value, joining a range with -.