Module dialog

Module dialog 

Structs

AlertDialog
AlertDialog is a modal dialog that interrupts the user with important content and expects a response.
Cancel
Confirm
Dialog
A modal to display content in a dialog box.
DialogAction
DialogButtonProps
Dialog button props.
DialogClose
DialogContent
Content container for a dialog.
DialogDescription
Description element for a dialog header.
DialogFooter
Footer section of a dialog, typically contains action buttons.
DialogHeader
Header section of a dialog, typically contains DialogTitle and DialogDescription.
DialogTitle
Title element for a dialog header.

Statics

ANIMATION_DURATION

Traits

DialogFooterButton