DialogButtonProps

Struct DialogButtonProps 

pub struct DialogButtonProps { /* private fields */ }
Dialog button props.

Implementations

Source

impl DialogButtonProps

pub fn ok_text(self, ok_text: impl Into<SharedString>) -> Self

Sets the text of the OK button. Default is OK.

pub fn ok_variant(self, ok_variant: ButtonVariant) -> Self

Sets the variant of the OK button. Default is ButtonVariant::Primary.

pub fn cancel_text(self, cancel_text: impl Into<SharedString>) -> Self

Sets the text of the Cancel button. Default is Cancel.

pub fn cancel_variant(self, cancel_variant: ButtonVariant) -> Self

Sets the variant of the Cancel button. Default is ButtonVariant::default().

pub fn show_cancel(self, show_cancel: bool) -> Self

Sets whether to show the Cancel button. Default is false.

pub fn on_ok( self, on_ok: impl Fn(&ClickEvent, &mut Window, &mut App) -> bool + 'static, ) -> Self

Sets the callback for when the dialog is has been confirmed.

The callback should return true to close the dialog, if return false the dialog will not be closed.

pub fn on_cancel( self, on_cancel: impl Fn(&ClickEvent, &mut Window, &mut App) -> bool + 'static, ) -> Self

Sets the callback for when the dialog is has been canceled.

The callback should return true to close the dialog, if return false the dialog will not be closed.