pub enum EmptyMediaVariant {
Default,
Icon,
}Expand description
Visual treatment for the media of an Empty state.
Variants
Default
Unframed content such as an image, avatar, or avatar group.
Icon
A muted, rounded two-rem frame for an icon.