pub enum Placement {
Top,
Bottom,
Left,
Right,
}Expand description
A enum for defining the placement of the element.
See also: Side if you need to define the left, right side.
Variants
Implementations