pub fn v_flex() -> DivExpand description
A column whose children stretch across the cross axis.
See StyledExt::v_flex for the cross-axis rule, which is not symmetric
with h_flex.
pub fn v_flex() -> DivA column whose children stretch across the cross axis.
See StyledExt::v_flex for the cross-axis rule, which is not symmetric
with h_flex.