pub struct SyntaxHighlighter { /* private fields */ }Expand description
A syntax highlighter that supports incremental parsing, multiline text, and caching of highlight results.
Implementations
Sourceimpl SyntaxHighlighter
impl SyntaxHighlighter
pub fn is_empty(&self) -> bool
Sourcepub fn update(&mut self, edit: Option<InputEdit>, text: &Rope)
pub fn update(&mut self, edit: Option<InputEdit>, text: &Rope)
Highlight the given text, returning a map from byte ranges to highlight captures.
Uses incremental parsing by edit to efficiently update the highlighter’s state.
Sourcepub fn styles(
&self,
range: &Range<usize>,
theme: &HighlightTheme,
) -> Vec<(Range<usize>, HighlightStyle)>
pub fn styles( &self, range: &Range<usize>, theme: &HighlightTheme, ) -> Vec<(Range<usize>, HighlightStyle)>
Returns the syntax highlight styles for a range of text.
The argument range is the range of bytes in the text to highlight.
Returns a vector of tuples where each tuple contains:
- A byte range relative to the text
- The corresponding highlight style for that range
Example
use gpui_component::highlighter::{HighlightTheme, SyntaxHighlighter};
use ropey::Rope;
let code = "fn main() {\n println!(\"Hello\");\n}";
let rope = Rope::from_str(code);
let mut highlighter = SyntaxHighlighter::new("rust");
highlighter.update(None, &rope);
let theme = HighlightTheme::default_dark();
let range = 0..code.len();
let styles = highlighter.styles(&range, &theme);Auto Trait Implementations
impl Freeze for SyntaxHighlighter
impl RefUnwindSafe for SyntaxHighlighter
impl Send for SyntaxHighlighter
impl Sync for SyntaxHighlighter
impl Unpin for SyntaxHighlighter
impl UnsafeUnpin for SyntaxHighlighter
impl UnwindSafe for SyntaxHighlighter