InputContentType

Enum InputContentType 

pub enum InputContentType {
Show 45 variants Name, NamePrefix, GivenName, MiddleName, FamilyName, NameSuffix, Nickname, JobTitle, OrganizationName, Location, FullStreetAddress, StreetAddressLine1, StreetAddressLine2, AddressCity, AddressState, AddressCityAndState, Sublocality, CountryName, PostalCode, TelephoneNumber, EmailAddress, Url, CreditCardNumber, CreditCardName, CreditCardGivenName, CreditCardMiddleName, CreditCardFamilyName, CreditCardSecurityCode, CreditCardExpiration, CreditCardExpirationMonth, CreditCardExpirationYear, CreditCardType, Username, Password, NewPassword, OneTimeCode, ShipmentTrackingNumber, FlightNumber, DateTime, Birthdate, BirthdateDay, BirthdateMonth, BirthdateYear, CellularEid, CellularImei,
}
Semantic content type for an Input.

These variants mirror Swift’s text content types.

Variants



Name

A person’s full name.



NamePrefix

A name prefix, such as Mr. or Dr.



GivenName

A person’s given name.



MiddleName

A person’s middle name.



FamilyName

A person’s family name.



NameSuffix

A name suffix, such as Jr. or PhD.



Nickname

A nickname.



JobTitle

A job title.



OrganizationName

An organization or company name.



Location

A location name.



FullStreetAddress

A full street address.



StreetAddressLine1

The first line of a street address.



StreetAddressLine2

The second line of a street address.



AddressCity

A city or locality.



AddressState

A state, province, or region.



AddressCityAndState

A combined city and state.



Sublocality

A sublocality, district, or neighborhood.



CountryName

A country name.



PostalCode

A postal or ZIP code.



TelephoneNumber

A telephone number.



EmailAddress

An email address.



Url

A URL.



CreditCardNumber

A credit card number.



CreditCardName

The full name on a credit card.



CreditCardGivenName

The given name on a credit card.



CreditCardMiddleName

The middle name on a credit card.



CreditCardFamilyName

The family name on a credit card.



CreditCardSecurityCode

The security code on a credit card.



CreditCardExpiration

A credit card expiration date.



CreditCardExpirationMonth

A credit card expiration month.



CreditCardExpirationYear

A credit card expiration year.



CreditCardType

A credit card type.



Username

A username or account identifier.



Password

The password for the account identified by the username field.



NewPassword

A new password, such as during sign up or password reset.



OneTimeCode

A one-time verification code.



ShipmentTrackingNumber

A parcel shipment tracking number.



FlightNumber

An airline flight number.



DateTime

A date, time, or duration.



Birthdate

A birthdate.



BirthdateDay

A birthdate day.



BirthdateMonth

A birthdate month.



BirthdateYear

A birthdate year.



CellularEid

An eSIM EID.



CellularImei

A cellular IMEI.