set_language_provider

Function set_language_provider 

pub fn set_language_provider(provider: Rc<dyn LanguageProvider>, cx: &mut App)
Install the application’s language service. Existing editors use the new service on their next editing operation, without waiting for a render. Registered configurations are retained and resolved through the new service.