#[non_exhaustive]pub struct LanguageConfig {
pub brackets: Vec<BracketPair>,
pub auto_closing_pairs: Option<Vec<AutoClosingPair>>,
pub auto_close_before: SharedString,
pub indentation_rules: Option<IndentationRules>,
}Expand description
Declarative language editing rules, independent of editor preferences and parsers.
Mirrors the supported subset of Monaco’s language configuration. None for
auto_closing_pairs uses brackets; Some(vec![]) disables all automatic pairs.
Use the builders to configure a default value; additional language capabilities
can be added without breaking callers. Tree-sitter queries are configured in
the parser implementation, not in these rules.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.brackets: Vec<BracketPair>auto_closing_pairs: Option<Vec<AutoClosingPair>>auto_close_before: SharedStringAutomatic insertion is allowed before these characters, whitespace, or EOF.
indentation_rules: Option<IndentationRules>Implementations
Sourceimpl LanguageConfig
impl LanguageConfig
pub fn brackets( self, pairs: impl IntoIterator<Item = BracketPair>, ) -> LanguageConfig
pub fn auto_closing_pairs( self, pairs: impl IntoIterator<Item = AutoClosingPair>, ) -> LanguageConfig
pub fn auto_close_before( self, characters: impl Into<SharedString>, ) -> LanguageConfig
pub fn indentation_rules(self, rules: IndentationRules) -> LanguageConfig