pub struct ListState<D: ListDelegate> { /* private fields */ }Expand description
The state for List.
List required all items has the same height.
Implementations
Sourceimpl<D> ListState<D>where
D: ListDelegate,
impl<D> ListState<D>where
D: ListDelegate,
pub fn new(delegate: D, window: &mut Window, cx: &mut Context<'_, Self>) -> Self
Sourcepub fn searchable(self, searchable: bool) -> Self
pub fn searchable(self, searchable: bool) -> Self
Sets whether the list is searchable, default is false.
When true, there will be a search input at the top of the list.
pub fn set_searchable(&mut self, searchable: bool, cx: &mut Context<'_, Self>)
Sourcepub fn selectable(self, selectable: bool) -> Self
pub fn selectable(self, selectable: bool) -> Self
Sets whether the list is selectable, default is true.
Sourcepub fn set_selectable(&mut self, selectable: bool, cx: &mut Context<'_, Self>)
pub fn set_selectable(&mut self, selectable: bool, cx: &mut Context<'_, Self>)
Sets whether the list is selectable, default is true.
pub fn delegate(&self) -> &D
pub fn delegate_mut(&mut self) -> &mut D
Sourcepub fn focus(&mut self, window: &mut Window, cx: &mut App)
pub fn focus(&mut self, window: &mut Window, cx: &mut App)
Focus the list, if the list is searchable, focus the search input.
Sourcepub fn set_selected_index(
&mut self,
ix: Option<IndexPath>,
window: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_selected_index( &mut self, ix: Option<IndexPath>, window: &mut Window, cx: &mut Context<'_, Self>, )
Set the selected index of the list, this method will not scroll to the selected item.
pub fn selected_index(&self) -> Option<IndexPath>
Sourcepub fn set_right_clicked_index(
&mut self,
ix: Option<IndexPath>,
window: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_right_clicked_index( &mut self, ix: Option<IndexPath>, window: &mut Window, cx: &mut Context<'_, Self>, )
Set the index of the item that has been right clicked.
Sourcepub fn right_clicked_index(&self) -> Option<IndexPath>
pub fn right_clicked_index(&self) -> Option<IndexPath>
Returns the index of the item that has been right clicked.
Sourcepub fn set_query(
&mut self,
query: &str,
window: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_query( &mut self, query: &str, window: &mut Window, cx: &mut Context<'_, Self>, )
Set the query text of the search input, this will trigger a search.
Sourcepub fn set_item_to_measure_index(
&mut self,
ix: IndexPath,
_: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_item_to_measure_index( &mut self, ix: IndexPath, _: &mut Window, cx: &mut Context<'_, Self>, )
Set a specific list item for measurement.
Sourcepub fn scroll_to_item(
&mut self,
ix: IndexPath,
strategy: ScrollStrategy,
_: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn scroll_to_item( &mut self, ix: IndexPath, strategy: ScrollStrategy, _: &mut Window, cx: &mut Context<'_, Self>, )
Scroll to the item at the given index.
Sourcepub fn scroll_handle(&self) -> &VirtualListScrollHandle
pub fn scroll_handle(&self) -> &VirtualListScrollHandle
Get scroll handle
pub fn scroll_to_selected_item( &mut self, _: &mut Window, cx: &mut Context<'_, Self>, )