pub struct NotificationSettings {
pub placement: Anchor,
pub margins: Edges<Pixels>,
pub max_items: usize,
pub width: Pixels,
pub delivery: NotificationDelivery,
}Expand description
The settings for notifications.
Fields
placement: AnchorThe placement of the notifications, default: Anchor::TopRight
A single notification can override this with Notification::placement.
margins: Edges<Pixels>The margins of the notification with respect to the window edges.
max_items: usizeThe maximum number of notifications to show at once, default: 10
width: PixelsThe width of the notifications, default: 382px
delivery: NotificationDeliveryWhere notifications are delivered, default: NotificationDelivery::InApp
A single notification can override this with Notification::delivery.