pub struct ScaleOrdinal<D, R> { /* private fields */ }Implementations
Sourceimpl<D, R> ScaleOrdinal<D, R>
impl<D, R> ScaleOrdinal<D, R>
pub fn new(domain: Vec<D>, range: Vec<R>) -> ScaleOrdinal<D, R>
Sourcepub fn domain(self, domain: Vec<D>) -> ScaleOrdinal<D, R>
pub fn domain(self, domain: Vec<D>) -> ScaleOrdinal<D, R>
Set the domain to the specified array of values.
Sourcepub fn range(self, range: Vec<R>) -> ScaleOrdinal<D, R>
pub fn range(self, range: Vec<R>) -> ScaleOrdinal<D, R>
Set the range of the ordinal scale to the specified array of values.
Sourcepub fn unknown(self, unknown: R) -> ScaleOrdinal<D, R>
pub fn unknown(self, unknown: R) -> ScaleOrdinal<D, R>
Set the output value of the scale for unknown input values and returns this scale.