pub enum SankeyError {
MissingNode(usize),
CircularLink,
}Expand description
A reason a Sankey layout could not be computed.
Variants
MissingNode(usize)
A link references a node index out of range.
CircularLink
The graph contains a circular link.