Area

Struct Area 

pub struct Area<T> { /* private fields */ }

Implementations

Source

impl<T> Area<T>

pub fn new() -> Self

pub fn data<I>(self, data: I) -> Self
where I: IntoIterator<Item = T>,

Set the data of the Area.

pub fn x<F>(self, x: F) -> Self
where F: Fn(&T) -> Option<f32> + 'static,

Set the x of the Area.

pub fn y0(self, y0: f32) -> Self

Set the y0 of the Area.

pub fn y1<F>(self, y1: F) -> Self
where F: Fn(&T) -> Option<f32> + 'static,

Set the y1 of the Area.

pub fn fill(self, fill: impl Into<Background>) -> Self

Set the fill color of the Area.

pub fn stroke(self, stroke: impl Into<Background>) -> Self

Set the stroke color of the Area.

pub fn stroke_style(self, stroke_style: StrokeStyle) -> Self

Set the stroke style of the Area.

pub fn paint_cached( &self, bounds: &Bounds<Pixels>, fill: &mut PathCache, line: &mut PathCache, window: &mut Window, )

Paint the Area, reusing the fill and stroke tessellated by an earlier paint while the projected points, baseline and curve style are unchanged. fill and line are the two caches this area keeps together; see Line::paint_cached.

pub fn paint(&self, bounds: &Bounds<Pixels>, window: &mut Window)

Paint the Area.