Module scroll

Module scroll 

Structs

AutoScroll
Manages timer-based auto-scrolling during drag interactions.
Scrollable
A scrollable element wrapper that renders the original element as the scroll area and overlays scrollbars.
ScrollableMask
Make a scrollable mask element to cover the parent view with the mouse wheel event listening.
Scrollbar
Scrollbar control for scroll-area or a uniform-list.
ScrollbarMotion
Motion tokens used by Scrollbar.
ScrollbarStyles
Typed paint styles supported by Scrollbar.
ScrollbarThumbStyle
Paint-only styles for a scrollbar thumb.
ScrollbarTrackStyle
Paint-only styles for a scrollbar track.

Enums

ScrollbarAxis
Scrollbar axis.
ScrollbarEntrance
How a scrollbar becomes visible.
ScrollbarMode
Scrollbar show mode.

Traits

ScrollableElement
A trait for elements that can be made scrollable with scrollbars.
ScrollbarHandle
A trait for scroll handles that can get and set offset.