Module searchable_list

Module searchable_list 

Re-exports

pub use change::SearchableListChange;
pub use state::SearchableListState;

Modules

change
state

Structs

SearchableGroup
A named group of items used for sectioned lists.
SearchableListItemElement
A single row element used inside searchable-list dropdowns (Select, ComboBox, MultiComboBox).
SearchableVec
A vector of items that supports incremental filtering.

Traits

SearchableListDelegate
Provides data and search behaviour to a searchable list component.
SearchableListItem
An item that can appear in a searchable list (Select, ComboBox).