pub struct SearchableGroup<I: SearchableListItem> {
pub title: SharedString,
pub items: Vec<I>,
}Expand description
A named group of items used for sectioned lists.
Fields
title: SharedStringitems: Vec<I>Implementations
Sourceimpl<I: SearchableListItem> SearchableGroup<I>
impl<I: SearchableListItem> SearchableGroup<I>
Sourcepub fn new(title: impl Into<SharedString>) -> Self
pub fn new(title: impl Into<SharedString>) -> Self
Create an empty group with the given section title.
Sourcepub fn items(self, items: impl IntoIterator<Item = I>) -> Self
pub fn items(self, items: impl IntoIterator<Item = I>) -> Self
Append multiple items to this group.