pub struct NumberFieldOptions {
pub min: f64,
pub max: f64,
pub step: f64,
}Fields
min: f64The minimum value for the number input, default is f64::MIN.
max: f64The maximum value for the number input, default is f64::MAX.
step: f64The step value for the number input, default is 1.0.