SettingPage

Struct SettingPage 

pub struct SettingPage { /* private fields */ }
A setting page that can contain multiple setting groups.

Implementations

Source

impl SettingPage

pub fn new(title: impl Into<SharedString>) -> Self

pub fn title(self, title: impl Into<SharedString>) -> Self

Set the title of the setting page.

pub fn title_suffix<F, E>(self, suffix: F) -> Self
where E: IntoElement, F: Fn(&mut Window, &mut App) -> E + 'static,

Set a custom element to render after the title in the page header.

For example, an info icon button that opens the help documentation.

pub fn icon(self, icon: impl Into<Icon>) -> Self

Set the icon of the setting page.

pub fn description(self, description: impl Into<SharedString>) -> Self

Set the description of the setting page, default is None.

pub fn default_open(self, default_open: bool) -> Self

Set the default open state of the setting page, default is false.

pub fn resettable(self, resettable: bool) -> Self

Set whether the setting page is resettable, default is true.

If true and the items in this page has changed, the reset button will appear.

pub fn group(self, group: SettingGroup) -> Self

Add a setting group to the page.

pub fn groups(self, groups: impl IntoIterator<Item = SettingGroup>) -> Self

Add multiple setting groups to the page.

pub fn header_style(self, style: &StyleRefinement) -> Self

Set the style refinement for the header of the setting page.