pub enum SpeechError {
PermissionDenied,
NoInputDevice,
Unsupported,
Input(Arc<Error>),
Recognizer(Arc<Error>),
}Expand description
Why a speech session failed.
Variants
PermissionDenied
The user or the system denied access to the microphone.
NoInputDevice
No audio input device is available.
Unsupported
Speech input is not supported on this platform or build.
Input(Arc<Error>)
The audio input failed or its device went away.
Recognizer(Arc<Error>)
The recognizer failed, e.g. it could not reach its service.
Implementations
Sourceimpl SpeechError
impl SpeechError
Sourcepub fn input(error: impl Into<Error>) -> Self
pub fn input(error: impl Into<Error>) -> Self
An SpeechError::Input from any error.
Sourcepub fn recognizer(error: impl Into<Error>) -> Self
pub fn recognizer(error: impl Into<Error>) -> Self
A SpeechError::Recognizer from any error.