Module table

Module table 

Structs

Column
Represents a column in a table, used for initializing table columns.
ColumnGroup
A column group can be used to group multiple columns under a single header.
DataTable
A table element with support for row, column, and cell selection.
Table
A basic table component for directly rendering tabular data.
TableBody
The body section of a Table, wrapping data rows.
TableCaption
A caption displayed below the Table.
TableCell
A data cell in a TableRow.
TableFooter
The footer section of a Table, wrapping footer rows.
TableHead
A header cell in a TableRow.
TableHeader
The header section of a Table, wrapping header rows.
TableRow
A row in a Table.
TableState
TableVisibleRange
The visible range of the rows and columns.

Enums

ColumnFixed
ColumnSort
The sorting behavior of a column.
TableEvent
The Table event.

Traits

TableDelegate
A delegate trait for providing data and rendering for a table.