pub struct DataTable<D: TableDelegate> { /* private fields */ }Expand description
A table element with support for row, column, and cell selection.
Features
- Multiple Selection Modes: Support for row, column, and cell selection
- Cell Selection: Click to select individual cells, with keyboard navigation
- Virtual Scrolling: Efficient rendering of large datasets
- Resizable Columns: Drag column borders to resize
- Movable Columns: Drag column headers to reorder
- Fixed Columns: Pin columns to the left side
- Sortable Columns: Click column headers to sort
- Context Menus: Right-click support for rows and cells
Cell Selection Mode
When cell selection is enabled via TableState::cell_selectable():
- Click on cells to select them
- A row header column appears on the left for selecting entire rows
(use
TableState::row_header()to hide it) - Keyboard navigation (arrow keys, Tab, Home, End, PageUp, PageDown) works at cell level
- Right-click and double-click events are supported
See TableState for more details on cell selection.
Example
ⓘ
let table_state = cx.new(|cx| {
TableState::new(delegate, cx)
.cell_selectable(true)
.row_selectable(true)
});
DataTable::new(&table_state)
.stripe(true)
.bordered(true)Implementations
Sourceimpl<D> DataTable<D>where
D: TableDelegate,
impl<D> DataTable<D>where
D: TableDelegate,
Sourcepub fn new(state: &Entity<TableState<D>>) -> Self
pub fn new(state: &Entity<TableState<D>>) -> Self
Create a new DataTable element with the given TableState.
Sourcepub fn stripe(self, stripe: bool) -> Self
pub fn stripe(self, stripe: bool) -> Self
Set to use stripe style of the table, default to false.
Sourcepub fn bordered(self, bordered: bool) -> Self
pub fn bordered(self, bordered: bool) -> Self
Set to use border style of the table, default to true.
Sourcepub fn scrollbar_visible(self, vertical: bool, horizontal: bool) -> Self
pub fn scrollbar_visible(self, vertical: bool, horizontal: bool) -> Self
Set scrollbar visibility.