pub fn markdown(source: impl Into<SharedString>) -> TextViewExpand description
Creates a Markdown text view identified by the caller’s code location.
pub fn markdown(source: impl Into<SharedString>) -> TextViewCreates a Markdown text view identified by the caller’s code location.