pub enum AlignKind {
Left,
Right,
Center,
None,
}Expand description
GFM: alignment of phrasing content.
Used to align the contents of table cells within a table.
Variants
Left
Left alignment.
See the left value of the text-align CSS property.
| | aaa |
> | | :-- |
^^^Right
Right alignment.
See the right value of the text-align CSS property.
| | aaa |
> | | --: |
^^^Center
Center alignment.
See the center value of the text-align CSS property.
| | aaa |
> | | :-: |
^^^None
No alignment.
Phrasing content is aligned as defined by the host environment.
| | aaa |
> | | --- |
^^^Trait Implementations
impl Copy for AlignKind
Sourceimpl<'de> Deserialize<'de> for AlignKind
Available on crate feature serde only.
impl<'de> Deserialize<'de> for AlignKind
Available on crate feature
serde only.Sourcefn deserialize<D>(
deserializer: D,
) -> Result<AlignKind, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<AlignKind, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AlignKind
Sourceimpl Serialize for AlignKind
Available on crate feature serde only.Implement serde according to https://github.com/syntax-tree/mdast#aligntype
impl Serialize for AlignKind
Available on crate feature
serde only.Implement serde according to https://github.com/syntax-tree/mdast#aligntype
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AlignKind