pub struct SemanticColorConfig {Show 17 fields
pub background: Option<SharedString>,
pub foreground: Option<SharedString>,
pub surface: Option<SharedString>,
pub surface_foreground: Option<SharedString>,
pub primary: Option<SharedString>,
pub primary_foreground: Option<SharedString>,
pub secondary: Option<SharedString>,
pub secondary_foreground: Option<SharedString>,
pub muted: Option<SharedString>,
pub muted_foreground: Option<SharedString>,
pub accent: Option<SharedString>,
pub accent_foreground: Option<SharedString>,
pub destructive: Option<SharedString>,
pub destructive_foreground: Option<SharedString>,
pub border: Option<SharedString>,
pub input: Option<SharedString>,
pub ring: Option<SharedString>,
}Fields
background: Option<SharedString>foreground: Option<SharedString>surface: Option<SharedString>surface_foreground: Option<SharedString>primary: Option<SharedString>primary_foreground: Option<SharedString>secondary: Option<SharedString>secondary_foreground: Option<SharedString>muted: Option<SharedString>muted_foreground: Option<SharedString>accent: Option<SharedString>accent_foreground: Option<SharedString>destructive: Option<SharedString>destructive_foreground: Option<SharedString>border: Option<SharedString>input: Option<SharedString>ring: Option<SharedString>Trait Implementations
Sourceimpl Clone for SemanticColorConfig
impl Clone for SemanticColorConfig
Sourcefn clone(&self) -> SemanticColorConfig
fn clone(&self) -> SemanticColorConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticColorConfig
impl Debug for SemanticColorConfig
Sourceimpl Default for SemanticColorConfig
impl Default for SemanticColorConfig
Sourcefn default() -> SemanticColorConfig
fn default() -> SemanticColorConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticColorConfigwhere
SemanticColorConfig: Default,
impl<'de> Deserialize<'de> for SemanticColorConfigwhere
SemanticColorConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticColorConfig
impl JsonSchema for SemanticColorConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticColorConfig
impl RefUnwindSafe for SemanticColorConfig
impl Send for SemanticColorConfig
impl Sync for SemanticColorConfig
impl Unpin for SemanticColorConfig
impl UnsafeUnpin for SemanticColorConfig
impl UnwindSafe for SemanticColorConfig