pub struct SemanticRadiusConfig {
pub none: Option<f32>,
pub sm: Option<f32>,
pub md: Option<f32>,
pub lg: Option<f32>,
pub xl: Option<f32>,
pub full: Option<f32>,
}Fields
none: Option<f32>sm: Option<f32>md: Option<f32>lg: Option<f32>xl: Option<f32>full: Option<f32>Trait Implementations
Sourceimpl Clone for SemanticRadiusConfig
impl Clone for SemanticRadiusConfig
Sourcefn clone(&self) -> SemanticRadiusConfig
fn clone(&self) -> SemanticRadiusConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticRadiusConfig
impl Debug for SemanticRadiusConfig
Sourceimpl Default for SemanticRadiusConfig
impl Default for SemanticRadiusConfig
Sourcefn default() -> SemanticRadiusConfig
fn default() -> SemanticRadiusConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticRadiusConfigwhere
SemanticRadiusConfig: Default,
impl<'de> Deserialize<'de> for SemanticRadiusConfigwhere
SemanticRadiusConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticRadiusConfig
impl JsonSchema for SemanticRadiusConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticRadiusConfig
impl RefUnwindSafe for SemanticRadiusConfig
impl Send for SemanticRadiusConfig
impl Sync for SemanticRadiusConfig
impl Unpin for SemanticRadiusConfig
impl UnsafeUnpin for SemanticRadiusConfig
impl UnwindSafe for SemanticRadiusConfig