pub struct SemanticShadowConfig {
pub sm: Option<Vec<BoxShadow>>,
pub md: Option<Vec<BoxShadow>>,
pub lg: Option<Vec<BoxShadow>>,
}Fields
sm: Option<Vec<BoxShadow>>md: Option<Vec<BoxShadow>>lg: Option<Vec<BoxShadow>>Trait Implementations
Sourceimpl Clone for SemanticShadowConfig
impl Clone for SemanticShadowConfig
Sourcefn clone(&self) -> SemanticShadowConfig
fn clone(&self) -> SemanticShadowConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticShadowConfig
impl Debug for SemanticShadowConfig
Sourceimpl Default for SemanticShadowConfig
impl Default for SemanticShadowConfig
Sourcefn default() -> SemanticShadowConfig
fn default() -> SemanticShadowConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticShadowConfigwhere
SemanticShadowConfig: Default,
impl<'de> Deserialize<'de> for SemanticShadowConfigwhere
SemanticShadowConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticShadowConfig
impl JsonSchema for SemanticShadowConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticShadowConfig
impl RefUnwindSafe for SemanticShadowConfig
impl Send for SemanticShadowConfig
impl Sync for SemanticShadowConfig
impl Unpin for SemanticShadowConfig
impl UnsafeUnpin for SemanticShadowConfig
impl UnwindSafe for SemanticShadowConfig