pub struct SemanticSpacingConfig {
pub xxs: Option<f32>,
pub xs: Option<f32>,
pub sm: Option<f32>,
pub md: Option<f32>,
pub lg: Option<f32>,
pub xl: Option<f32>,
pub xxl: Option<f32>,
}Fields
xxs: Option<f32>xs: Option<f32>sm: Option<f32>md: Option<f32>lg: Option<f32>xl: Option<f32>xxl: Option<f32>Trait Implementations
Sourceimpl Clone for SemanticSpacingConfig
impl Clone for SemanticSpacingConfig
Sourcefn clone(&self) -> SemanticSpacingConfig
fn clone(&self) -> SemanticSpacingConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticSpacingConfig
impl Debug for SemanticSpacingConfig
Sourceimpl Default for SemanticSpacingConfig
impl Default for SemanticSpacingConfig
Sourcefn default() -> SemanticSpacingConfig
fn default() -> SemanticSpacingConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticSpacingConfigwhere
SemanticSpacingConfig: Default,
impl<'de> Deserialize<'de> for SemanticSpacingConfigwhere
SemanticSpacingConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticSpacingConfig
impl JsonSchema for SemanticSpacingConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticSpacingConfig
impl RefUnwindSafe for SemanticSpacingConfig
impl Send for SemanticSpacingConfig
impl Sync for SemanticSpacingConfig
impl Unpin for SemanticSpacingConfig
impl UnsafeUnpin for SemanticSpacingConfig
impl UnwindSafe for SemanticSpacingConfig