pub struct SemanticThemeConfig {
pub colors: SemanticColorConfig,
pub radius: SemanticRadiusConfig,
pub spacing: SemanticSpacingConfig,
pub typography: SemanticTypographyConfig,
pub shadow: SemanticShadowConfig,
}Fields
colors: SemanticColorConfigradius: SemanticRadiusConfigspacing: SemanticSpacingConfigtypography: SemanticTypographyConfigshadow: SemanticShadowConfigTrait Implementations
Sourceimpl Clone for SemanticThemeConfig
impl Clone for SemanticThemeConfig
Sourcefn clone(&self) -> SemanticThemeConfig
fn clone(&self) -> SemanticThemeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticThemeConfig
impl Debug for SemanticThemeConfig
Sourceimpl Default for SemanticThemeConfig
impl Default for SemanticThemeConfig
Sourcefn default() -> SemanticThemeConfig
fn default() -> SemanticThemeConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticThemeConfigwhere
SemanticThemeConfig: Default,
impl<'de> Deserialize<'de> for SemanticThemeConfigwhere
SemanticThemeConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticThemeConfig
impl JsonSchema for SemanticThemeConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticThemeConfig
impl RefUnwindSafe for SemanticThemeConfig
impl Send for SemanticThemeConfig
impl Sync for SemanticThemeConfig
impl Unpin for SemanticThemeConfig
impl UnsafeUnpin for SemanticThemeConfig
impl UnwindSafe for SemanticThemeConfig