pub struct SemanticThemeConfigFile {
pub tokens: SemanticThemeConfig,
}Expand description
Standalone semantic theme configuration file.
This wrapper is intentionally separate from ThemeConfig so adding
semantic tokens does not change the legacy public struct shape.
Fields
tokens: SemanticThemeConfigTrait Implementations
Sourceimpl Clone for SemanticThemeConfigFile
impl Clone for SemanticThemeConfigFile
Sourcefn clone(&self) -> SemanticThemeConfigFile
fn clone(&self) -> SemanticThemeConfigFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticThemeConfigFile
impl Debug for SemanticThemeConfigFile
Sourceimpl Default for SemanticThemeConfigFile
impl Default for SemanticThemeConfigFile
Sourcefn default() -> SemanticThemeConfigFile
fn default() -> SemanticThemeConfigFile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticThemeConfigFilewhere
SemanticThemeConfigFile: Default,
impl<'de> Deserialize<'de> for SemanticThemeConfigFilewhere
SemanticThemeConfigFile: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticThemeConfigFile
impl JsonSchema for SemanticThemeConfigFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticThemeConfigFile
impl RefUnwindSafe for SemanticThemeConfigFile
impl Send for SemanticThemeConfigFile
impl Sync for SemanticThemeConfigFile
impl Unpin for SemanticThemeConfigFile
impl UnsafeUnpin for SemanticThemeConfigFile
impl UnwindSafe for SemanticThemeConfigFile