pub struct ThemeColor {Show 139 fields
pub accent: Hsla,
pub accent_foreground: Hsla,
pub accordion: Hsla,
pub background: Hsla,
pub border: Hsla,
pub button: Hsla,
pub button_active: Hsla,
pub button_foreground: Hsla,
pub button_hover: Hsla,
pub button_danger: Hsla,
pub button_danger_active: Hsla,
pub button_danger_foreground: Hsla,
pub button_danger_hover: Hsla,
pub button_info: Hsla,
pub button_info_active: Hsla,
pub button_info_foreground: Hsla,
pub button_info_hover: Hsla,
pub button_primary: Hsla,
pub button_primary_active: Hsla,
pub button_primary_foreground: Hsla,
pub button_primary_hover: Hsla,
pub button_secondary: Hsla,
pub button_secondary_active: Hsla,
pub button_secondary_foreground: Hsla,
pub button_secondary_hover: Hsla,
pub button_success: Hsla,
pub button_success_active: Hsla,
pub button_success_foreground: Hsla,
pub button_success_hover: Hsla,
pub button_warning: Hsla,
pub button_warning_active: Hsla,
pub button_warning_foreground: Hsla,
pub button_warning_hover: Hsla,
pub group_box: Hsla,
pub group_box_foreground: Hsla,
pub caret: Hsla,
pub chart_1: Hsla,
pub chart_2: Hsla,
pub chart_3: Hsla,
pub chart_4: Hsla,
pub chart_5: Hsla,
pub chart_bullish: Hsla,
pub chart_bearish: Hsla,
pub danger: Hsla,
pub danger_active: Hsla,
pub danger_foreground: Hsla,
pub danger_hover: Hsla,
pub description_list_label: Hsla,
pub description_list_label_foreground: Hsla,
pub drag_border: Hsla,
pub drop_target: Hsla,
pub foreground: Hsla,
pub info: Hsla,
pub info_active: Hsla,
pub info_foreground: Hsla,
pub info_hover: Hsla,
pub input: Hsla,
pub link: Hsla,
pub link_active: Hsla,
pub link_hover: Hsla,
pub list: Hsla,
pub list_active: Hsla,
pub list_active_border: Hsla,
pub list_even: Hsla,
pub list_head: Hsla,
pub list_hover: Hsla,
pub muted: Hsla,
pub muted_foreground: Hsla,
pub popover: Hsla,
pub popover_foreground: Hsla,
pub primary: Hsla,
pub primary_active: Hsla,
pub primary_foreground: Hsla,
pub primary_hover: Hsla,
pub progress_bar: Hsla,
pub ring: Hsla,
pub scrollbar: Hsla,
pub scrollbar_thumb: Hsla,
pub scrollbar_thumb_hover: Hsla,
pub secondary: Hsla,
pub secondary_active: Hsla,
pub secondary_foreground: Hsla,
pub secondary_hover: Hsla,
pub selection: Hsla,
pub sidebar: Hsla,
pub sidebar_accent: Hsla,
pub sidebar_accent_foreground: Hsla,
pub sidebar_border: Hsla,
pub sidebar_foreground: Hsla,
pub sidebar_primary: Hsla,
pub sidebar_primary_foreground: Hsla,
pub skeleton: Hsla,
pub slider_bar: Hsla,
pub slider_thumb: Hsla,
pub success: Hsla,
pub success_foreground: Hsla,
pub success_hover: Hsla,
pub success_active: Hsla,
pub switch: Hsla,
pub switch_thumb: Hsla,
pub tab: Hsla,
pub tab_active: Hsla,
pub tab_active_foreground: Hsla,
pub tab_bar: Hsla,
pub tab_bar_segmented: Hsla,
pub tab_foreground: Hsla,
pub table: Hsla,
pub table_active: Hsla,
pub table_active_border: Hsla,
pub table_even: Hsla,
pub table_head: Hsla,
pub table_head_foreground: Hsla,
pub table_foot: Hsla,
pub table_foot_foreground: Hsla,
pub table_hover: Hsla,
pub table_row_border: Hsla,
pub title_bar: Hsla,
pub title_bar_border: Hsla,
pub status_bar: Hsla,
pub status_bar_border: Hsla,
pub tiles: Hsla,
pub warning: Hsla,
pub warning_active: Hsla,
pub warning_hover: Hsla,
pub warning_foreground: Hsla,
pub overlay: Hsla,
pub window_border: Hsla,
pub red: Hsla,
pub red_light: Hsla,
pub green: Hsla,
pub green_light: Hsla,
pub blue: Hsla,
pub blue_light: Hsla,
pub yellow: Hsla,
pub yellow_light: Hsla,
pub magenta: Hsla,
pub magenta_light: Hsla,
pub cyan: Hsla,
pub cyan_light: Hsla,
}Expand description
Theme colors used throughout the UI components.
Fields
accent: HslaUsed for accents such as hover background on MenuItem, ListItem, etc.
accent_foreground: HslaUsed for accent text color.
accordion: HslaAccordion background color.
background: HslaDefault background color.
border: HslaDefault border color
Default Button background color.
Default Button active background color.
Default Button text color.
Default Button hover background color.
Button danger background color, fallback to danger.
Button danger active background color, fallback to danger_active.
Button danger text color, fallback to danger_foreground.
Button danger hover background color, fallback to danger_hover.
Button info background color, fallback to info.
Button info active background color, fallback to info_active.
Button info text color, fallback to info_foreground.
Button info hover background color, fallback to info_hover.
Button primary background color, fallback to primary.
Button primary active background color, fallback to primary_active.
Button primary text color, fallback to primary_foreground.
Button primary hover background color, fallback to primary_hover.
Button secondary background color, fallback to secondary.
Button secondary active background color, fallback to secondary_active.
Button secondary text color, fallback to secondary_foreground.
Button secondary hover background color, fallback to secondary_hover.
Button success background color, fallback to success.
Button success active background color, fallback to success_active.
Button success text color, fallback to success_foreground.
Button success hover background color, fallback to success_hover.
Button warning background color, fallback to warning.
Button warning active background color, fallback to warning_active.
Button warning text color, fallback to warning_foreground.
Button warning hover background color, fallback to warning_hover.
group_box: HslaBackground color for GroupBox.
group_box_foreground: HslaText color for GroupBox.
caret: HslaInput caret color (Blinking cursor).
chart_1: HslaChart 1 color.
chart_2: HslaChart 2 color.
chart_3: HslaChart 3 color.
chart_4: HslaChart 4 color.
chart_5: HslaChart 5 color.
chart_bullish: HslaBullish color for candlestick charts (upward price movement).
chart_bearish: HslaBearish color for candlestick charts (downward price movement).
danger: HslaDanger background color.
danger_active: HslaDanger active background color.
danger_foreground: HslaDanger text color.
danger_hover: HslaDanger hover background color.
description_list_label: HslaDescription List label background color.
description_list_label_foreground: HslaDescription List label foreground color.
drag_border: HslaDrag border color.
drop_target: HslaDrop target background color.
foreground: HslaDefault text color.
info: HslaInfo background color.
info_active: HslaInfo active background color.
info_foreground: HslaInfo text color.
info_hover: HslaInfo hover background color.
input: HslaBorder color for inputs such as Input, Select, etc.
link: HslaLink text color.
link_active: HslaActive link text color.
link_hover: HslaHover link text color.
list: HslaBackground color for List and ListItem.
list_active: HslaBackground color for active ListItem.
list_active_border: HslaBorder color for active ListItem.
list_even: HslaStripe background color for even ListItem.
list_head: HslaBackground color for List header.
list_hover: HslaHover background color for ListItem.
muted: HslaMuted backgrounds such as Skeleton and Switch.
muted_foreground: HslaMuted text color, as used in disabled text.
popover: HslaBackground color for Popover.
popover_foreground: HslaText color for Popover.
primary: HslaPrimary background color.
primary_active: HslaActive primary background color.
primary_foreground: HslaPrimary text color.
primary_hover: HslaHover primary background color.
progress_bar: HslaProgress bar background color.
ring: HslaUsed for focus ring.
scrollbar: HslaScrollbar background color.
scrollbar_thumb: HslaScrollbar thumb background color.
scrollbar_thumb_hover: HslaScrollbar thumb hover background color.
secondary: HslaSecondary background color.
secondary_active: HslaActive secondary background color.
secondary_foreground: HslaSecondary text color, used for secondary Button text color or secondary text.
secondary_hover: HslaHover secondary background color.
selection: HslaInput selection background color.
Sidebar background color.
Sidebar accent background color.
Sidebar accent text color.
Sidebar border color.
Sidebar text color.
Sidebar primary background color.
Sidebar primary text color.
skeleton: HslaSkeleton background color.
slider_bar: HslaSlider bar background color.
slider_thumb: HslaSlider thumb background color.
success: HslaSuccess background color.
success_foreground: HslaSuccess text color.
success_hover: HslaSuccess hover background color.
success_active: HslaSuccess active background color.
switch: HslaSwitch background color.
switch_thumb: HslaSwitch thumb background color.
tab: HslaTab background color.
tab_active: HslaTab active background color.
tab_active_foreground: HslaTab active text color.
tab_bar: HslaTabBar background color.
tab_bar_segmented: HslaTabBar segmented background color.
tab_foreground: HslaTab text color.
table: HslaTable background color.
table_active: HslaTable active item background color.
table_active_border: HslaTable active item border color.
table_even: HslaStripe background color for even TableRow.
table_head: HslaTable head background color.
table_head_foreground: HslaTable head text color.
table_foot: HslaTable footer background color.
table_foot_foreground: HslaTable footer text color.
table_hover: HslaTable item hover background color.
table_row_border: HslaTable row border color.
title_bar: HslaTitleBar background color, use for Window title bar.
title_bar_border: HslaTitleBar border color.
status_bar: HslaStatusBar background color, use for the bottom status bar.
status_bar_border: HslaStatusBar border color.
tiles: HslaBackground color for Tiles.
warning: HslaWarning background color.
warning_active: HslaWarning active background color.
warning_hover: HslaWarning hover background color.
warning_foreground: HslaWarning foreground color.
overlay: HslaOverlay background color.
window_border: HslaWindow border color.
Platform specific:
This is only works on Linux, other platforms we can’t change the window border color.
red: HslaThe base red color.
red_light: HslaThe base red light color.
green: HslaThe base green color.
green_light: HslaThe base green light color.
blue: HslaThe base blue color.
blue_light: HslaThe base blue light color.
yellow: HslaThe base yellow color.
yellow_light: HslaThe base yellow light color.
magenta: HslaThe base magenta color.
magenta_light: HslaThe base magenta light color.
cyan: HslaThe base cyan color.
cyan_light: HslaThe base cyan light color.
Implementations