ThemeConfigColors

Struct ThemeConfigColors 

pub struct ThemeConfigColors {
Show 128 fields pub accent: Option<SharedString>, pub accent_foreground: Option<SharedString>, pub accordion: Option<SharedString>, pub background: Option<SharedString>, pub border: Option<SharedString>, pub button: Option<SharedString>, pub button_active: Option<SharedString>, pub button_foreground: Option<SharedString>, pub button_hover: Option<SharedString>, pub button_danger: Option<SharedString>, pub button_danger_active: Option<SharedString>, pub button_danger_foreground: Option<SharedString>, pub button_danger_hover: Option<SharedString>, pub button_info: Option<SharedString>, pub button_info_active: Option<SharedString>, pub button_info_foreground: Option<SharedString>, pub button_info_hover: Option<SharedString>, pub button_primary: Option<SharedString>, pub button_primary_active: Option<SharedString>, pub button_primary_foreground: Option<SharedString>, pub button_primary_hover: Option<SharedString>, pub button_secondary: Option<SharedString>, pub button_secondary_active: Option<SharedString>, pub button_secondary_foreground: Option<SharedString>, pub button_secondary_hover: Option<SharedString>, pub button_success: Option<SharedString>, pub button_success_active: Option<SharedString>, pub button_success_foreground: Option<SharedString>, pub button_success_hover: Option<SharedString>, pub button_warning: Option<SharedString>, pub button_warning_active: Option<SharedString>, pub button_warning_foreground: Option<SharedString>, pub button_warning_hover: Option<SharedString>, pub group_box: Option<SharedString>, pub group_box_foreground: Option<SharedString>, pub group_box_title_foreground: Option<SharedString>, pub caret: Option<SharedString>, pub chart_1: Option<SharedString>, pub chart_2: Option<SharedString>, pub chart_3: Option<SharedString>, pub chart_4: Option<SharedString>, pub chart_5: Option<SharedString>, pub chart_bullish: Option<SharedString>, pub chart_bearish: Option<SharedString>, pub danger: Option<SharedString>, pub danger_active: Option<SharedString>, pub danger_foreground: Option<SharedString>, pub danger_hover: Option<SharedString>, pub description_list_label: Option<SharedString>, pub description_list_label_foreground: Option<SharedString>, pub drag_border: Option<SharedString>, pub drop_target: Option<SharedString>, pub foreground: Option<SharedString>, pub info: Option<SharedString>, pub info_active: Option<SharedString>, pub info_foreground: Option<SharedString>, pub info_hover: Option<SharedString>, pub input: Option<SharedString>, pub link: Option<SharedString>, pub link_active: Option<SharedString>, pub link_hover: Option<SharedString>, pub list: Option<SharedString>, pub list_active: Option<SharedString>, pub list_active_border: Option<SharedString>, pub list_even: Option<SharedString>, pub list_head: Option<SharedString>, pub list_hover: Option<SharedString>, pub muted: Option<SharedString>, pub muted_foreground: Option<SharedString>, pub popover: Option<SharedString>, pub popover_foreground: Option<SharedString>, pub primary: Option<SharedString>, pub primary_active: Option<SharedString>, pub primary_foreground: Option<SharedString>, pub primary_hover: Option<SharedString>, pub progress_bar: Option<SharedString>, pub ring: Option<SharedString>, pub scrollbar: Option<SharedString>, pub scrollbar_thumb: Option<SharedString>, pub scrollbar_thumb_hover: Option<SharedString>, pub secondary: Option<SharedString>, pub secondary_active: Option<SharedString>, pub secondary_foreground: Option<SharedString>, pub secondary_hover: Option<SharedString>, pub selection: Option<SharedString>, pub sidebar: Option<SharedString>, pub sidebar_accent: Option<SharedString>, pub sidebar_accent_foreground: Option<SharedString>, pub sidebar_border: Option<SharedString>, pub sidebar_foreground: Option<SharedString>, pub sidebar_primary: Option<SharedString>, pub sidebar_primary_foreground: Option<SharedString>, pub skeleton: Option<SharedString>, pub slider_bar: Option<SharedString>, pub slider_thumb: Option<SharedString>, pub success: Option<SharedString>, pub success_foreground: Option<SharedString>, pub success_hover: Option<SharedString>, pub success_active: Option<SharedString>, pub switch: Option<SharedString>, pub switch_thumb: Option<SharedString>, pub tab: Option<SharedString>, pub tab_active: Option<SharedString>, pub tab_active_foreground: Option<SharedString>, pub tab_bar: Option<SharedString>, pub tab_bar_segmented: Option<SharedString>, pub tab_foreground: Option<SharedString>, pub table: Option<SharedString>, pub table_active: Option<SharedString>, pub table_active_border: Option<SharedString>, pub table_even: Option<SharedString>, pub table_head: Option<SharedString>, pub table_head_foreground: Option<SharedString>, pub table_foot: Option<SharedString>, pub table_foot_foreground: Option<SharedString>, pub table_hover: Option<SharedString>, pub table_row_border: Option<SharedString>, pub title_bar: Option<SharedString>, pub title_bar_border: Option<SharedString>, pub status_bar: Option<SharedString>, pub status_bar_border: Option<SharedString>, pub tiles: Option<SharedString>, pub warning: Option<SharedString>, pub warning_active: Option<SharedString>, pub warning_hover: Option<SharedString>, pub warning_foreground: Option<SharedString>, pub overlay: Option<SharedString>, pub window_border: Option<SharedString>, /* private fields */
}

Fields

accent: Option<SharedString>

Used for accents such as hover background on MenuItem, ListItem, etc.

accent_foreground: Option<SharedString>

Used for accent text color.

accordion: Option<SharedString>

Accordion background color.

background: Option<SharedString>

Default background color.

border: Option<SharedString>

Default border color

button: Option<SharedString>

Default Button background color.

button_active: Option<SharedString>

Default Button active background color.

button_foreground: Option<SharedString>

Default Button text color.

button_hover: Option<SharedString>

Default Button hover background color.

button_danger: Option<SharedString>

Button danger background color, fallback to danger.

button_danger_active: Option<SharedString>

Button danger active background color, fallback to danger_active.

button_danger_foreground: Option<SharedString>

Button danger text color, fallback to danger_foreground.

button_danger_hover: Option<SharedString>

Button danger hover background color, fallback to danger_hover.

button_info: Option<SharedString>

Button info background color, fallback to info.

button_info_active: Option<SharedString>

Button info active background color, fallback to info_active.

button_info_foreground: Option<SharedString>

Button info text color, fallback to info_foreground.

button_info_hover: Option<SharedString>

Button info hover background color, fallback to info_hover.

button_primary: Option<SharedString>

Button primary background color, fallback to primary.

button_primary_active: Option<SharedString>

Button primary active background color, fallback to primary_active.

button_primary_foreground: Option<SharedString>

Button primary text color, fallback to primary_foreground.

button_primary_hover: Option<SharedString>

Button primary hover background color, fallback to primary_hover.

button_secondary: Option<SharedString>

Button secondary background color, fallback to secondary.

button_secondary_active: Option<SharedString>

Button secondary active background color, fallback to secondary_active.

button_secondary_foreground: Option<SharedString>

Button secondary text color, fallback to secondary_foreground.

button_secondary_hover: Option<SharedString>

Button secondary hover background color, fallback to secondary_hover.

button_success: Option<SharedString>

Button success background color, fallback to success.

button_success_active: Option<SharedString>

Button success active background color, fallback to success_active.

button_success_foreground: Option<SharedString>

Button success text color, fallback to success_foreground.

button_success_hover: Option<SharedString>

Button success hover background color, fallback to success_hover.

button_warning: Option<SharedString>

Button warning background color, fallback to warning.

button_warning_active: Option<SharedString>

Button warning active background color, fallback to warning_active.

button_warning_foreground: Option<SharedString>

Button warning text color, fallback to warning_foreground.

button_warning_hover: Option<SharedString>

Button warning hover background color, fallback to warning_hover.

group_box: Option<SharedString>

Background color for GroupBox.

group_box_foreground: Option<SharedString>

Text color for GroupBox.

group_box_title_foreground: Option<SharedString>

Title text color for GroupBox.

caret: Option<SharedString>

Input caret color (Blinking cursor).

chart_1: Option<SharedString>

Chart 1 color.

chart_2: Option<SharedString>

Chart 2 color.

chart_3: Option<SharedString>

Chart 3 color.

chart_4: Option<SharedString>

Chart 4 color.

chart_5: Option<SharedString>

Chart 5 color.

chart_bullish: Option<SharedString>

Bullish color for candlestick charts (upward price movement).

chart_bearish: Option<SharedString>

Bearish color for candlestick charts (downward price movement).

danger: Option<SharedString>

Danger background color.

danger_active: Option<SharedString>

Danger active background color.

danger_foreground: Option<SharedString>

Danger text color.

danger_hover: Option<SharedString>

Danger hover background color.

description_list_label: Option<SharedString>

Description List label background color.

description_list_label_foreground: Option<SharedString>

Description List label foreground color.

drag_border: Option<SharedString>

Drag border color.

drop_target: Option<SharedString>

Drop target background color.

foreground: Option<SharedString>

Default text color.

info: Option<SharedString>

Info background color.

info_active: Option<SharedString>

Info active background color.

info_foreground: Option<SharedString>

Info text color.

info_hover: Option<SharedString>

Info hover background color.

input: Option<SharedString>

Border color for inputs such as Input, Select, etc.

link: Option<SharedString>

Link text color.

link_active: Option<SharedString>

Active link text color.

link_hover: Option<SharedString>

Hover link text color.

list: Option<SharedString>

Background color for List and ListItem.

list_active: Option<SharedString>

Background color for active ListItem.

list_active_border: Option<SharedString>

Border color for active ListItem.

list_even: Option<SharedString>

Stripe background color for even ListItem.

list_head: Option<SharedString>

Background color for List header.

list_hover: Option<SharedString>

Hover background color for ListItem.

muted: Option<SharedString>

Muted backgrounds such as Skeleton and Switch.

muted_foreground: Option<SharedString>

Muted text color, as used in disabled text.

popover: Option<SharedString>

Background color for Popover.

popover_foreground: Option<SharedString>

Text color for Popover.

primary: Option<SharedString>

Primary background color.

primary_active: Option<SharedString>

Active primary background color.

primary_foreground: Option<SharedString>

Primary text color.

primary_hover: Option<SharedString>

Hover primary background color.

progress_bar: Option<SharedString>

Progress bar background color.

ring: Option<SharedString>

Used for focus ring.

scrollbar: Option<SharedString>

Scrollbar background color.

scrollbar_thumb: Option<SharedString>

Scrollbar thumb background color.

scrollbar_thumb_hover: Option<SharedString>

Scrollbar thumb hover background color.

secondary: Option<SharedString>

Secondary background color.

secondary_active: Option<SharedString>

Active secondary background color.

secondary_foreground: Option<SharedString>

Secondary text color, used for secondary Button text color or secondary text.

secondary_hover: Option<SharedString>

Hover secondary background color.

selection: Option<SharedString>

Input selection background color.

sidebar: Option<SharedString>

Sidebar background color.

sidebar_accent: Option<SharedString>

Sidebar accent background color.

sidebar_accent_foreground: Option<SharedString>

Sidebar accent text color.

sidebar_border: Option<SharedString>

Sidebar border color.

sidebar_foreground: Option<SharedString>

Sidebar text color.

sidebar_primary: Option<SharedString>

Sidebar primary background color.

sidebar_primary_foreground: Option<SharedString>

Sidebar primary text color.

skeleton: Option<SharedString>

Skeleton background color.

slider_bar: Option<SharedString>

Slider bar background color.

slider_thumb: Option<SharedString>

Slider thumb background color.

success: Option<SharedString>

Success background color.

success_foreground: Option<SharedString>

Success text color.

success_hover: Option<SharedString>

Success hover background color.

success_active: Option<SharedString>

Success active background color.

switch: Option<SharedString>

Switch background color.

switch_thumb: Option<SharedString>

Switch thumb background color.

tab: Option<SharedString>

Tab background color.

tab_active: Option<SharedString>

Tab active background color.

tab_active_foreground: Option<SharedString>

Tab active text color.

tab_bar: Option<SharedString>

TabBar background color.

tab_bar_segmented: Option<SharedString>

TabBar segmented background color.

tab_foreground: Option<SharedString>

Tab text color.

table: Option<SharedString>

Table background color.

table_active: Option<SharedString>

Table active item background color.

table_active_border: Option<SharedString>

Table active item border color.

table_even: Option<SharedString>

Stripe background color for even TableRow.

table_head: Option<SharedString>

Table header background color.

table_head_foreground: Option<SharedString>

Table header text color.

table_foot: Option<SharedString>

Table footer background color.

table_foot_foreground: Option<SharedString>

Table footer text color.

table_hover: Option<SharedString>

Table item hover background color.

table_row_border: Option<SharedString>

Table row border color.

title_bar: Option<SharedString>

TitleBar background color, use for Window title bar.

title_bar_border: Option<SharedString>

TitleBar border color.

status_bar: Option<SharedString>

StatusBar background color, use for the bottom status bar.

status_bar_border: Option<SharedString>

StatusBar border color.

tiles: Option<SharedString>

Background color for Tiles.

warning: Option<SharedString>

Warning background color.

warning_active: Option<SharedString>

Warning active background color.

warning_hover: Option<SharedString>

Warning hover background color.

warning_foreground: Option<SharedString>

Warning foreground color.

overlay: Option<SharedString>

Overlay background color.

window_border: Option<SharedString>

Window border color.

Platform specific:

This is only works on Linux, other platforms we can’t change the window border color.