pub struct ThemeToken {
pub color: Hsla,
pub background: Background,
}Expand description
A theme token that keeps a solid representative color and its renderable background.
Fields
color: Hslabackground: BackgroundImplementations
Sourceimpl ThemeToken
impl ThemeToken
pub fn new(color: Hsla, background: Background) -> Self
Methods from Deref<Target = Hsla>
Sourcepub fn is_transparent(&self) -> bool
pub fn is_transparent(&self) -> bool
Returns true if the HSLA color is fully transparent, false otherwise.
Sourcepub fn is_opaque(&self) -> bool
pub fn is_opaque(&self) -> bool
Returns true if the HSLA color is fully opaque, false otherwise.
Sourcepub fn grayscale(&self) -> Hsla
pub fn grayscale(&self) -> Hsla
Returns a new HSLA color with the same hue, and lightness, but with no saturation.
Sourcepub fn opacity(&self, factor: f32) -> Hsla
pub fn opacity(&self, factor: f32) -> Hsla
Multiplies the alpha value of the color by a given factor and returns a new HSLA color.
Useful for transforming colors with dynamic opacity, like a color from an external source.
Example:
let color = gpui::red();
let faded_color = color.opacity(0.5);
assert_eq!(faded_color.a, 0.5);This will return a red color with half the opacity.
Example:
use gpui::hsla;
let color = hsla(0.7, 1.0, 0.5, 0.7); // A saturated blue
let faded_color = color.opacity(0.16);
assert!((faded_color.a - 0.112).abs() < 1e-6);This will return a blue color with around ~10% opacity, suitable for an element’s hover or selected state.
Sourcepub fn alpha(&self, a: f32) -> Hsla
pub fn alpha(&self, a: f32) -> Hsla
Returns a new HSLA color with the same hue, saturation, and lightness, but with a new alpha value.
Example:
let color = gpui::red();
let red_color = color.alpha(0.25);
assert_eq!(red_color.a, 0.25);This will return a red color with 25% opacity.
Example:
use gpui::hsla;
let color = hsla(0.7, 1.0, 0.5, 0.7); // A saturated blue
let faded_color = color.alpha(0.25);
assert_eq!(faded_color.a, 0.25);This will return a blue color with 25% opacity.