pub trait IconNamed {
// Required method
fn path(self) -> SharedString;
}Expand description
A named icon that resolves to a path in an application’s asset source.
Implement this for custom icon sets accepted by GPUI Component’s Icon.
Required Methods
fn path(self) -> SharedString
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".