StyledExt

Trait StyledExt 

pub trait StyledExt: Styled + Sized {
Show 23 methods // Provided methods fn refine_style(self, style: &StyleRefinement) -> Self { ... } fn h_flex(self) -> Self { ... } fn v_flex(self) -> Self { ... } fn paddings<L>(self, paddings: impl Into<Edges<L>>) -> Self where L: Into<DefiniteLength> + Clone + Default + Debug + PartialEq { ... } fn margins<L>(self, margins: impl Into<Edges<L>>) -> Self where L: Into<DefiniteLength> + Clone + Default + Debug + PartialEq { ... } fn debug_red(self) -> Self { ... } fn debug_blue(self) -> Self { ... } fn debug_yellow(self) -> Self { ... } fn debug_green(self) -> Self { ... } fn debug_pink(self) -> Self { ... } fn debug_focused( self, focus_handle: &FocusHandle, window: &Window, cx: &App, ) -> Self { ... } fn focused_border(self, cx: &App) -> Self { ... } fn font_thin(self) -> Self { ... } fn font_extralight(self) -> Self { ... } fn font_light(self) -> Self { ... } fn font_normal(self) -> Self { ... } fn font_medium(self) -> Self { ... } fn font_semibold(self) -> Self { ... } fn font_bold(self) -> Self { ... } fn font_extrabold(self) -> Self { ... } fn font_black(self) -> Self { ... } fn popover_style(self, cx: &App) -> Self { ... } fn corner_radii(self, radius: Corners<Pixels>) -> Self { ... }
}
Extends gpui::Styled with specific styling methods.

Provided Methods

fn refine_style(self, style: &StyleRefinement) -> Self

Refine the style of this element, applying the given style refinement.

fn h_flex(self) -> Self

Apply self into a horizontal flex layout.

fn v_flex(self) -> Self

Apply self into a vertical flex layout.

fn paddings<L>(self, paddings: impl Into<Edges<L>>) -> Self

Apply paddings to the element.

fn margins<L>(self, margins: impl Into<Edges<L>>) -> Self

Apply margins to the element.

fn debug_red(self) -> Self

Render a border with a width of 1px, color red

fn debug_blue(self) -> Self

Render a border with a width of 1px, color blue

fn debug_yellow(self) -> Self

Render a border with a width of 1px, color yellow

fn debug_green(self) -> Self

Render a border with a width of 1px, color green

fn debug_pink(self) -> Self

Render a border with a width of 1px, color pink

fn debug_focused( self, focus_handle: &FocusHandle, window: &Window, cx: &App, ) -> Self

Render a 1px blue border, when if the element is focused

fn focused_border(self, cx: &App) -> Self

Render a border with a width of 1px, color ring color

fn font_thin(self) -> Self

fn font_extralight(self) -> Self

fn font_light(self) -> Self

fn font_normal(self) -> Self

fn font_medium(self) -> Self

fn font_semibold(self) -> Self

fn font_bold(self) -> Self

fn font_extrabold(self) -> Self

fn font_black(self) -> Self

fn popover_style(self, cx: &App) -> Self

Set as Popover style

fn corner_radii(self, radius: Corners<Pixels>) -> Self

Set corner radii for the element.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E: Styled> StyledExt for E