Module tree

Module tree 

Structs

Tree
A styled tree view that preserves the legacy gpui-component API while delegating tree behavior and interaction state to gpui-base.
TreeEntry
A flat representation of a tree item with its depth.
TreeItem
A tree item with a stable id, display label, children, and shared state.
TreeState
Behavior and interaction state for a virtualized tree.

Enums

TreeEvent
Event emitted by a tree when user-visible expansion state changes.

Functions

tree
Create a Tree.