Structs
- Backspace
- Buffer
Point - Position in the buffer (logical text).
- Code
Action Item - Completion
Menu Options - Display options for the LSP completion popover.
- Copy
- Cut
- Delete
- Delete
ToBeginning OfLine - Delete
ToEnd OfLine - Delete
ToNext Word End - Delete
ToPrevious Word Start - Display
Map - DisplayMap is the main interface for Editor/Input coordinate mapping.
- Display
Point - Final display position (after soft-wrapping and folding).
- Editor
- A styled source-code editor.
- Editor
Mode - Source code, with language features: the mode of
crate::input::EditorState. - Enter
- Escape
- Fold
Range - A foldable line range supplied by an editor highlighter or another source.
- GoTo
Definition - Hover
Popover State - Indent
- Indent
Inline - Input
- A text input element bind to an
InputState. - Input
Edit - Parser-independent description of an incremental text replacement.
- Input
Mode - A single-line text field: the mode of
crate::input::InputState. - Lsp
- LSP ServerCapabilities
- Move
Down - MoveEnd
- Move
Home - Move
Left - Move
Page Down - Move
Page Up - Move
Right - Move
ToEnd - Move
ToEnd OfLine - Move
ToNext Word - Move
ToPrevious Word - Move
ToStart - Move
ToStart OfLine - MoveUp
- Number
Input - A number input element with increment and decrement buttons.
- OtpInput
- A One Time Password (OTP) input element.
- OtpState
- Stateful input and focus behavior for a fixed-length numeric one-time code.
- Outdent
- Outdent
Inline - Paste
- Point
- Parser-independent byte/row/column position used for incremental edits.
- Position
- Position in a text document expressed as zero-based line and character offset. A position is between two characters like an ‘insert’ cursor in a editor.
- Redo
- Replace
- Rope
- A utf8 text rope.
- Rope
Lines - An iterator over the lines of a
Rope. - Search
- Select
All - Select
ToEnd - Select
ToEnd OfLine - Select
ToNext Word End - Select
ToPrevious Word Start - Select
ToStart - Select
ToStart OfLine - Selection
- A selection in the text, represented by start and end byte indices.
- Show
Character Palette - TabSize
- Text
Decoration - A presentation style applied to a UTF-8 byte range in an input.
- Text
Decoration Collection - An independently managed collection of
TextDecorations. - Textarea
- A styled ordinary multi-line text field.
- Textarea
Mode - Ordinary multi-line text: the mode of
crate::input::TextareaState. - Toggle
Code Actions - Tree
- Undo
Enums
- AnyInput
State - Any input-like state, regardless of which input element renders it.
- Input
Content Type - Semantic content type for an
Input. - Input
Event - Mask
Pattern - Number
Input Event - Number
Step - Strategy used by numeric editors when stepping their value.
- OtpEvent
- A semantic notification from a one-time-code state.
- Step
Action - Wrapping
Indent - Controls how soft-wrapped continuation lines are indented.
Traits
- Code
Action Provider - Completion
Provider - A trait for providing code completions based on the current input state and context.
- Definition
Provider - Definition provider
- Document
Color Provider - Document
Range Semantic Tokens Provider - A provider of semantic highlighting tokens, layered on top of the
built-in tree-sitter
SyntaxHighlighter. - Highlight
Style Resolver - Resolves semantic highlight names into renderable GPUI styles.
- Hover
Provider - Hover provider
- Input
Highlighter - Parser-independent syntax highlighting seam consumed by the Base editor.
- Input
Mode Kind - Hooks the shared engine calls back into for mode-specific work.
- RopeExt
- An extension trait for
Ropeto provide additional utility methods.
Type Aliases
- Editor
State - State for source-code editing.
- Input
Highlighter Factory - Input
State - State for a single-line text input.
- Show
Document Handler - Host hook to show a document when following an LSP location
(Go to Definition), modeled after the
window/showDocumentrequest. - Textarea
State - State for editing ordinary multi-line text.