ScaleOrdinal

Struct ScaleOrdinal 

pub struct ScaleOrdinal<D, R> { /* private fields */ }

Implementations

Source

impl<D, R> ScaleOrdinal<D, R>

pub fn new(domain: Vec<D>, range: Vec<R>) -> Self

pub fn domain(self, domain: Vec<D>) -> Self

Set the domain to the specified array of values.

pub fn range(self, range: Vec<R>) -> Self

Set the range of the ordinal scale to the specified array of values.

pub fn unknown(self, unknown: R) -> Self

Set the output value of the scale for unknown input values and returns this scale.

Source

impl<D, R> ScaleOrdinal<D, R>
where D: PartialEq, R: Clone,

pub fn map(&self, value: &D) -> Option<R>

Given a value in the input domain, returns the corresponding value in the output range.