pub struct Area<T> { /* private fields */ }Implementations
Sourceimpl<T> Area<T>
impl<T> Area<T>
pub fn new() -> Self
Sourcepub fn data<I>(self, data: I) -> Selfwhere
I: IntoIterator<Item = T>,
pub fn data<I>(self, data: I) -> Selfwhere
I: IntoIterator<Item = T>,
Set the data of the Area.
Sourcepub fn fill(self, fill: impl Into<Background>) -> Self
pub fn fill(self, fill: impl Into<Background>) -> Self
Set the fill color of the Area.
Sourcepub fn stroke(self, stroke: impl Into<Background>) -> Self
pub fn stroke(self, stroke: impl Into<Background>) -> Self
Set the stroke color of the Area.
Sourcepub fn stroke_style(self, stroke_style: StrokeStyle) -> Self
pub fn stroke_style(self, stroke_style: StrokeStyle) -> Self
Set the stroke style of the Area.
Sourcepub fn paint_cached(
&self,
bounds: &Bounds<Pixels>,
fill: &mut PathCache,
line: &mut PathCache,
window: &mut Window,
)
pub fn paint_cached( &self, bounds: &Bounds<Pixels>, fill: &mut PathCache, line: &mut PathCache, window: &mut Window, )
Paint the Area, reusing the fill and stroke tessellated by an earlier
paint while the projected points, baseline and curve style are
unchanged. fill and line are the two caches this area keeps
together; see Line::paint_cached.