Re-exports
pub use change::SearchableListChange;pub use state::SearchableListState;
Modules
Structs
- Searchable
Group - A named group of items used for sectioned lists.
- Searchable
List Item Element - A single row element used inside searchable-list dropdowns (Select, ComboBox, MultiComboBox).
- Searchable
Vec - A vector of items that supports incremental filtering.
Traits
- Searchable
List Delegate - Provides data and search behaviour to a searchable list component.
- Searchable
List Item - An item that can appear in a searchable list (Select, ComboBox).