pub struct SelectState<D: SearchableListDelegate + 'static>{ /* private fields */ }Expand description
State of the Select component.
Implementations
Sourceimpl<D> SelectState<D>where
D: SearchableListDelegate + 'static,
<D::Item as SearchableListItem>::Value: PartialEq + Clone,
impl<D> SelectState<D>where
D: SearchableListDelegate + 'static,
<D::Item as SearchableListItem>::Value: PartialEq + Clone,
Sourcepub fn new(
delegate: D,
selected_index: Option<IndexPath>,
window: &mut Window,
cx: &mut Context<'_, Self>,
) -> Self
pub fn new( delegate: D, selected_index: Option<IndexPath>, window: &mut Window, cx: &mut Context<'_, Self>, ) -> Self
Create a new Select state.
Sourcepub fn searchable(self, searchable: bool) -> Self
pub fn searchable(self, searchable: bool) -> Self
Sets whether the dropdown menu is searchable, default is false.
When true, a search input appears at the top of the dropdown menu.
Sourcepub fn set_selected_index(
&mut self,
selected_index: Option<IndexPath>,
window: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_selected_index( &mut self, selected_index: Option<IndexPath>, window: &mut Window, cx: &mut Context<'_, Self>, )
Set the selected index for the select.
Sourcepub fn set_selected_value(
&mut self,
selected_value: &<D::Item as SearchableListItem>::Value,
window: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_selected_value( &mut self, selected_value: &<D::Item as SearchableListItem>::Value, window: &mut Window, cx: &mut Context<'_, Self>, )
Set selected value for the select.
Looks up the position from the delegate and sets the selected index accordingly.
Passes None when the value is not found.
The delegate looks the value up in its matched items, so an active search query is cleared first to get an index into the full item list.
Sourcepub fn set_items(
&mut self,
items: D,
_: &mut Window,
cx: &mut Context<'_, Self>,
)where
D: SearchableListDelegate + 'static,
pub fn set_items(
&mut self,
items: D,
_: &mut Window,
cx: &mut Context<'_, Self>,
)where
D: SearchableListDelegate + 'static,
Replace the delegate (item data) for the select state.
Sourcepub fn selected_index(&self, cx: &App) -> Option<IndexPath>
pub fn selected_index(&self, cx: &App) -> Option<IndexPath>
Get the current selected index.
Sourcepub fn selected_value(&self) -> Option<&<D::Item as SearchableListItem>::Value>
pub fn selected_value(&self) -> Option<&<D::Item as SearchableListItem>::Value>
Get the current selected value.