pub struct SettingPage { /* private fields */ }Expand description
A setting page that can contain multiple setting groups.
Implementations
Sourceimpl SettingPage
impl SettingPage
pub fn new(title: impl Into<SharedString>) -> Self
Sourcepub fn title(self, title: impl Into<SharedString>) -> Self
pub fn title(self, title: impl Into<SharedString>) -> Self
Set the title of the setting page.
Sourcepub fn title_suffix<F, E>(self, suffix: F) -> Self
pub fn title_suffix<F, E>(self, suffix: F) -> Self
Set a custom element to render after the title in the page header.
For example, an info icon button that opens the help documentation.
Sourcepub fn description(self, description: impl Into<SharedString>) -> Self
pub fn description(self, description: impl Into<SharedString>) -> Self
Set the description of the setting page, default is None.
Sourcepub fn default_open(self, default_open: bool) -> Self
pub fn default_open(self, default_open: bool) -> Self
Set the default open state of the setting page, default is false.
Sourcepub fn resettable(self, resettable: bool) -> Self
pub fn resettable(self, resettable: bool) -> Self
Set whether the setting page is resettable, default is true.
If true and the items in this page has changed, the reset button will appear.
Sourcepub fn group(self, group: SettingGroup) -> Self
pub fn group(self, group: SettingGroup) -> Self
Add a setting group to the page.
Sourcepub fn groups(self, groups: impl IntoIterator<Item = SettingGroup>) -> Self
pub fn groups(self, groups: impl IntoIterator<Item = SettingGroup>) -> Self
Add multiple setting groups to the page.
Sourcepub fn header_style(self, style: &StyleRefinement) -> Self
pub fn header_style(self, style: &StyleRefinement) -> Self
Set the style refinement for the header of the setting page.