Structs
- Column
- Represents a column in a table, used for initializing table columns.
- Column
Group - A column group can be used to group multiple columns under a single header.
- Data
Table - A table element with support for row, column, and cell selection.
- Table
- A basic table component for directly rendering tabular data.
- Table
Body - The body section of a
Table, wrapping data rows. - Table
Caption - A caption displayed below the
Table. - Table
Cell - A data cell in a
TableRow. - Table
Footer - The footer section of a
Table, wrapping footer rows. - Table
Head - A header cell in a
TableRow. - Table
Header - The header section of a
Table, wrapping header rows. - Table
Row - A row in a
Table. - Table
State - Table
Visible Range - The visible range of the rows and columns.
Enums
- Column
Fixed - Column
Sort - The sorting behavior of a column.
- Table
Event - The Table event.
Traits
- Table
Delegate - A delegate trait for providing data and rendering for a table.