Module text

Module text 

Compatibility facade for rich text now owned by gpui-base.

Modules

markdown_ast
markdown syntax tree: mdast.

Structs

MarkdownExtensions
Registry for custom Markdown parsing and rendering.
MarkdownNode
A custom Markdown node produced by MarkdownExtensions.
MarkdownParseContext
Context passed to custom Markdown parsers.
TableData
Plain snapshot of a rendered Markdown table, passed to the crate::text::TextView::table_actions hook.
TextView
The component-level rich text element.
TextViewLayoutState
Layout state retained for source compatibility with the original component TextView.
TextViewPrepaintState
Prepaint state retained for source compatibility with the original component TextView.
TextViewState
The state of a TextView.
TextViewStyle
TextViewStyle used to customize the style for super::TextView.

Enums

SelectionFormat
The format of the text returned by TextViewState::selected_text, which is also what copy writes to the clipboard.
Text
Either a plain string or a rich TextView.

Traits

MarkdownPlugin
A reusable Markdown extension that parses and renders one custom node.
TextViewPlugin
A bundle of TextView configuration that can be applied in one call.

Functions

html
Creates an HTML text view identified by the caller’s code location.
markdown
Creates a Markdown text view identified by the caller’s code location.

Type Aliases

MarkdownBlockParserFn
Type for a custom Markdown block parser.
MarkdownBlockRenderFn
Type for a custom Markdown block renderer.