Compatibility facade for rich text now owned by gpui-base.
Modules
- markdown_
ast - markdown syntax tree: mdast.
Structs
- Markdown
Extensions - Registry for custom Markdown parsing and rendering.
- Markdown
Node - A custom Markdown node produced by
MarkdownExtensions. - Markdown
Parse Context - Context passed to custom Markdown parsers.
- Table
Data - Plain snapshot of a rendered Markdown table, passed to the
crate::text::TextView::table_actionshook. - Text
View - The component-level rich text element.
- Text
View Layout State - Layout state retained for source compatibility with the original component TextView.
- Text
View Prepaint State - Prepaint state retained for source compatibility with the original component TextView.
- Text
View State - The state of a TextView.
- Text
View Style - TextViewStyle used to customize the style for
super::TextView.
Enums
- Selection
Format - The format of the text returned by
TextViewState::selected_text, which is also what copy writes to the clipboard. - Text
- Either a plain string or a rich
TextView.
Traits
- Markdown
Plugin - A reusable Markdown extension that parses and renders one custom node.
- Text
View Plugin - A bundle of
TextViewconfiguration that can be applied in one call.
Functions
- html
- Creates an HTML text view identified by the caller’s code location.
- markdown
- Creates a Markdown text view identified by the caller’s code location.
Type Aliases
- Markdown
Block Parser Fn - Type for a custom Markdown block parser.
- Markdown
Block Render Fn - Type for a custom Markdown block renderer.