pub trait StyledExt: Styled + Sized {
Show 23 methods
// Provided methods
fn refine_style(self, style: &StyleRefinement) -> Self { ... }
fn h_flex(self) -> Self { ... }
fn v_flex(self) -> Self { ... }
fn paddings<L>(self, paddings: impl Into<Edges<L>>) -> Self
where L: Into<DefiniteLength> + Clone + Default + Debug + PartialEq { ... }
fn margins<L>(self, margins: impl Into<Edges<L>>) -> Self
where L: Into<DefiniteLength> + Clone + Default + Debug + PartialEq { ... }
fn debug_red(self) -> Self { ... }
fn debug_blue(self) -> Self { ... }
fn debug_yellow(self) -> Self { ... }
fn debug_green(self) -> Self { ... }
fn debug_pink(self) -> Self { ... }
fn debug_focused(
self,
focus_handle: &FocusHandle,
window: &Window,
cx: &App,
) -> Self { ... }
fn focused_border(self, cx: &App) -> Self { ... }
fn font_thin(self) -> Self { ... }
fn font_extralight(self) -> Self { ... }
fn font_light(self) -> Self { ... }
fn font_normal(self) -> Self { ... }
fn font_medium(self) -> Self { ... }
fn font_semibold(self) -> Self { ... }
fn font_bold(self) -> Self { ... }
fn font_extrabold(self) -> Self { ... }
fn font_black(self) -> Self { ... }
fn popover_style(self, cx: &App) -> Self { ... }
fn corner_radii(self, radius: Corners<Pixels>) -> Self { ... }
}Expand description
Extends gpui::Styled with specific styling methods.
Provided Methods
Sourcefn refine_style(self, style: &StyleRefinement) -> Self
fn refine_style(self, style: &StyleRefinement) -> Self
Refine the style of this element, applying the given style refinement.
Sourcefn debug_blue(self) -> Self
fn debug_blue(self) -> Self
Render a border with a width of 1px, color blue
Sourcefn debug_yellow(self) -> Self
fn debug_yellow(self) -> Self
Render a border with a width of 1px, color yellow
Sourcefn debug_green(self) -> Self
fn debug_green(self) -> Self
Render a border with a width of 1px, color green
Sourcefn debug_pink(self) -> Self
fn debug_pink(self) -> Self
Render a border with a width of 1px, color pink
Sourcefn debug_focused(
self,
focus_handle: &FocusHandle,
window: &Window,
cx: &App,
) -> Self
fn debug_focused( self, focus_handle: &FocusHandle, window: &Window, cx: &App, ) -> Self
Render a 1px blue border, when if the element is focused
Sourcefn focused_border(self, cx: &App) -> Self
fn focused_border(self, cx: &App) -> Self
Render a border with a width of 1px, color ring color
Sourcefn font_extralight(self) -> Self
fn font_extralight(self) -> Self
Sourcefn font_light(self) -> Self
fn font_light(self) -> Self
Sourcefn font_normal(self) -> Self
fn font_normal(self) -> Self
Sourcefn font_medium(self) -> Self
fn font_medium(self) -> Self
Sourcefn font_semibold(self) -> Self
fn font_semibold(self) -> Self
Sourcefn font_extrabold(self) -> Self
fn font_extrabold(self) -> Self
Sourcefn font_black(self) -> Self
fn font_black(self) -> Self
Sourcefn popover_style(self, cx: &App) -> Self
fn popover_style(self, cx: &App) -> Self
Set as Popover style
Sourcefn corner_radii(self, radius: Corners<Pixels>) -> Self
fn corner_radii(self, radius: Corners<Pixels>) -> Self
Set corner radii for the element.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".