Structs
- Tree
- A styled tree view that preserves the legacy
gpui-componentAPI while delegating tree behavior and interaction state togpui-base. - Tree
Entry - A flat representation of a tree item with its depth.
- Tree
Item - A tree item with a stable id, display label, children, and shared state.
- Tree
State - Behavior and interaction state for a virtualized tree.
Enums
- Tree
Event - Event emitted by a tree when user-visible expansion state changes.